@@ -3,18 +3,18 @@ Login command
 """
 
 import logging
+import os
 
 import click
 
+from aicrowd.auth.exceptions import CredentialException
+from aicrowd.auth.helpers import verify_api_key
 from aicrowd.constants import LoginConstants
 from aicrowd.contexts import ConfigContext
 from aicrowd.errors import INVALID_CREDENTIALS
 
-from aicrowd.auth.helpers import verify_api_key
-from aicrowd.auth.exceptions import CredentialException
 
-
-def aicrowd_login(api_key: str, config_context: ConfigContext = ConfigContext()):
+def aicrowd_login(api_key: str = None, config_context: ConfigContext = ConfigContext()):
     """
     Log in using AIcrowd API Key
 
@@ -25,6 +25,10 @@ def aicrowd_login(api_key: str, config_context: ConfigContext = ConfigContext())
     config = config_context.config
     log = logging.getLogger()
 
+    # if api_key not provided, check if env variable was declared
+    if api_key is None:
+        api_key = os.getenv("AICROWD_API_KEY", "")
+
     log.info("Verifying API Key...")
 
     if not verify_api_key(api_key):
