@@ -6,6 +6,7 @@ import sys
 from typing import List
 
 import click
+from git import exc
 
 from aicrowd.contexts import (
     pass_config,
@@ -14,6 +15,7 @@ from aicrowd.contexts import (
     ChallengeContext,
 )
 from aicrowd.utils import AliasedGroup, CommandWithExamples
+from aicrowd.utils.utils import exception_handler
 
 
 @click.group(name="dataset", cls=AliasedGroup)
@@ -27,6 +29,7 @@ def dataset_command():
 @click.option("-c", "--challenge", type=str, help="Specify challenge explicitly")
 @pass_challenge
 @pass_config
+@exception_handler
 def list_subcommand(
     config_ctx: ConfigContext, challenge_ctx: ChallengeContext, challenge: str
 ):
@@ -34,15 +37,8 @@ def list_subcommand(
     List the dataset files
     """
     from aicrowd.dataset import list_dataset
-    from aicrowd.dataset.exceptions import DatasetException
 
-    try:
-        list_dataset(challenge, False, config_ctx, challenge_ctx)
-    except DatasetException as e:
-        click.echo(click.style(e.message, fg="red"))
-        if e.fix:
-            click.echo(click.style(e.fix, fg="yellow"))
-        sys.exit(e.exit_code)
+    list_dataset(challenge, False, config_ctx, challenge_ctx)
 
 
 @click.command(name="download", cls=CommandWithExamples)
@@ -58,6 +54,7 @@ def list_subcommand(
 @click.argument("datasets", nargs=-1, type=str)
 @pass_challenge
 @pass_config
+@exception_handler
 def download_subcommand(
     config_ctx: ConfigContext,
     challenge_ctx: ChallengeContext,
@@ -84,17 +81,8 @@ def download_subcommand(
       aicrowd dataset download -c CHALLENGE -j 4
     """
     from aicrowd.dataset import download_dataset
-    from aicrowd.dataset.exceptions import DatasetException
 
-    try:
-        download_dataset(
-            challenge, output_dir, jobs, datasets, config_ctx, challenge_ctx
-        )
-    except DatasetException as e:
-        click.echo(click.style(e.message, fg="red"))
-        if e.fix:
-            click.echo(click.style(e.fix, fg="yellow"))
-        sys.exit(e.exit_code)
+    download_dataset(challenge, output_dir, jobs, datasets, config_ctx, challenge_ctx)
 
 
 dataset_command.add_command(list_subcommand)
