@@ -6,9 +6,7 @@ import os
 
 RAILS_HOST = os.getenv("RAILS_HOST", "www.aicrowd.com")
 RAILS_API_ENDPOINT = f"https://{RAILS_HOST}/api/v1"
-AICROWD_API_ENDPOINT = os.getenv(
-    "AICROWD_API_ENDPOINT", "https://aicrowd-api.aws-internal.k8s.aicrowd.com"
-)
+AICROWD_API_ENDPOINT = os.getenv("AICROWD_API_ENDPOINT", "https://api.aicrowd.com")
 
 DATASETS_HOST = os.getenv("DATASETS_HOST", "datasets.aicrowd.com")
 
@@ -19,6 +17,7 @@ class LoginConstants:
     """
 
     CONFIG_KEY = "aicrowd_api_key"
+    URL_LOGIN_REQUEST_LIFETIME = 120
 
 
 class ChallengeConstants:
