@@ -4,6 +4,10 @@ Exceptions that the CLI raises
 All other exceptions will inherit from `CLIException` so just catching that should be enough
 """
 
+import re
+
+import click
+
 from aicrowd import errors
 
 
@@ -27,12 +31,22 @@ class CLIException(Exception):
         self.fix = fix
         self.exit_code = exit_code
 
-    def __repr__(self):
+    def __str__(self):
         exception_name = type(self).__name__
+        exception_suffix = "Exception"
+
+        if exception_name.endswith(exception_suffix):
+            exception_name = exception_name[: -len(exception_suffix)]
+
+        # https://stackoverflow.com/a/9283563
+        # Convert PascalCase to Human Readable form smartly
+        exception_name = re.sub(
+            r"((?<=[a-z])[A-Z]|(?<!\A)[A-Z](?=[a-z]))", r" \1", exception_name
+        )
 
         if self.fix:
-            fix = f"\nFix: {self.fix}"
+            fix = click.style(f"\n{self.fix}", fg="yellow")
         else:
             fix = ""
 
-        return f"{exception_name}\nError: {self.message}{fix}"
+        return click.style(f"{exception_name} Error: {self.message}", fg="red") + fix
