@@ -3,7 +3,6 @@ import json
 import os
 import re
 import shutil
-import subprocess
 import time
 from types import ModuleType
 from typing import List, Dict, Any, Tuple
@@ -11,6 +10,7 @@ from urllib.parse import unquote
 
 import requests
 
+from aicrowd.notebook import exceptions
 from aicrowd.utils.jupyter import is_google_colab_env, mount_google_drive
 
 
@@ -44,17 +44,18 @@ def delete_expressions_from_notebook(
     # TODO: Duplicated code, refactor
     for _cell in nb["cells"]:
         # Match the lines only in code blocks
-        if _cell["cell_type"] == "code":
-            source_code = []
-            for _code_line in _cell["source"]:
-                matched = False
-                for _expr in expressions:
-                    if re.search(_expr, _code_line):
-                        matched = True
-                        break
-                if not matched:
-                    source_code.append(_code_line)
-            _cell["source"] = source_code
+        if _cell["cell_type"] != "code":
+            continue
+        source_code = []
+        for _code_line in _cell["source"]:
+            matched = False
+            for _expr in expressions:
+                if re.search(_expr, _code_line):
+                    matched = True
+                    break
+            if not matched:
+                source_code.append(_code_line)
+        _cell["source"] = source_code
     return nb
 
 
@@ -82,10 +83,14 @@ def get_latest_jupyter_session() -> Dict[str, Any]:
         headers={"Authorization": f"token {auto_detected_jupyter_token}"},
     )
     if not response.ok:
-        raise requests.exceptions.HTTPError(
+        raise exceptions.InvalidJupyterResponse(
             f"Got invalid response from Jupyter: {response.text}"
         )
     sessions = response.json()
+    if len(sessions) == 0:
+        raise exceptions.NotebookNotFound(
+            "No active notebook detected. Is your notebook kernel running?"
+        )
     latest_session = sorted(
         sessions,
         reverse=True,
@@ -104,7 +109,21 @@ def get_notebook_path():
 
 
 def get_jupyter_notebook_path():
-    return os.path.join(os.getcwd(), get_latest_jupyter_session()["path"])
+    latest_session = get_latest_jupyter_session()
+    server_info = get_jupyter_server_info()
+
+    notebook_root_dir = server_info.get("notebook_dir")
+    if notebook_root_dir is None:
+        notebook_root_dir = server_info.get("root_dir")
+    if notebook_root_dir is None:
+        notebook_root_dir = os.getcwd()
+    notebook_path = os.path.join(notebook_root_dir, latest_session["path"])
+    if os.path.exists(notebook_path):
+        return os.path.abspath(notebook_path)
+
+    raise exceptions.NotebookNotFound(
+        "Could not locate the absolute path to the jupyter notebook"
+    )
 
 
 def get_colab_notebook_path():
@@ -112,13 +131,13 @@ def get_colab_notebook_path():
     return os.path.join(
         mount_path,
         "MyDrive/Colab Notebooks",
-        unquote(get_latest_jupyter_session()["path"]),
+        unquote(get_latest_jupyter_session()["name"]),
     )
 
 
 def bundle_notebook(submission_dir: str, notebook_name: str = None):
     if is_google_colab_env():
-        raise NotImplementedError("Google colab submissions are not ready yet")
+        raise exceptions.FeatureNotReady("Google colab submissions are not ready yet")
     else:
         bundle_original_jupyter_notebook(submission_dir, notebook_name)
 
@@ -155,7 +174,7 @@ def get_kernel_from_language(language: str) -> str:
         return "python"
     if language.lower() == "r":
         return "ir"
-    raise NotImplementedError("Unsupported language")
+    raise exceptions.FeatureNotReady("Unsupported language")
 
 
 def import_module(module_name: str) -> ModuleType:
@@ -165,6 +184,29 @@ def import_module(module_name: str) -> ModuleType:
         pass
 
 
+def get_jupyter_server_info() -> Dict[str, str]:
+    """
+    Returns the latest jupyter server info
+    """
+    notebook_server = import_module("jupyter_server.serverapp")
+    if not notebook_server:
+        # print("No jupyter lab module found. Using jupyter notebook.")
+        notebook_server = import_module("notebook.notebookapp")
+
+    if not notebook_server:
+        # print("No jupyter notebook or lab modules found. Using the default values.")
+        return {}
+
+    session_list = list(notebook_server.list_running_servers())
+    if len(session_list) > 1:
+        print("WARNING: Got more than 1 jupyter server, selecting the latest session")
+    if len(session_list) == 0:
+        raise exceptions.NotebookNotFound(
+            "No jupyter server found. Did you start your jupyter server?"
+        )
+    return session_list[-1]
+
+
 def get_jupyter_server_endpoint() -> Tuple[str, str]:
     """
     Returns the jupyter server endpoint along with the token
@@ -172,20 +214,8 @@ def get_jupyter_server_endpoint() -> Tuple[str, str]:
     Returns:
         Jupyter server endpoint and token
     """
-    notebook_server = import_module("jupyter_server.serverapp")
-    if not notebook_server:
-        print("No jupyter lab module found. Using jupyter notebook.")
-        notebook_server = import_module("notebook.notebookapp")
-
-    if not notebook_server:
-        print("No jupyter notebook module found. Using default values.")
-        return get_default_jupyter_api_session_host(), ""
-
-    session_list = list(notebook_server.list_running_servers())
-    if len(session_list) > 1:
-        print("WARNING: Got more than 1 jupyter server, selecting the latest session")
-    if len(session_list) == 0:
-        raise RuntimeError(
-            "No jupyter server found. Did you start your jupyter server?"
-        )
-    return session_list[-1]["url"], session_list[-1]["token"]
+    server_info = get_jupyter_server_info()
+    return (
+        server_info.get("url", get_default_jupyter_api_session_host()),
+        server_info.get("token", ""),
+    )
